Enum BlockEvent
#[repr(i32)]pub enum BlockEvent {
Unspecified = 0,
BeginBlock = 1,
EndBlock = 2,
}Expand description
enum to specify that the IndexerTendermintEvent is a block event.
Variants
Unspecified = 0
Default value. This value is invalid and unused.
BeginBlock = 1
BLOCK_EVENT_BEGIN_BLOCK indicates that the event was generated during BeginBlock.
EndBlock = 2
BLOCK_EVENT_END_BLOCK indicates that the event was generated during EndBlock.
Implementations
impl BlockEvent
impl BlockEvent
impl BlockEvent
impl BlockEvent
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<BlockEvent>
pub fn from_str_name(value: &str) -> Option<BlockEvent>
Creates an enum from field names used in the ProtoBuf definition.