Enum OrderingWithinBlock
pub enum OrderingWithinBlock {
TransactionIndex(u32),
BlockEvent(i32),
}Expand description
ordering_within_block is either the transaction index or a boolean indicating the event was generated during processing the block rather than any specific transaction e.g. during FinalizeBlock.
Variants
Implementations
impl OrderingWithinBlock
impl OrderingWithinBlock
pub fn encode(&self, buf: &mut impl BufMut)
pub fn encode(&self, buf: &mut impl BufMut)
Encodes the message to a buffer.
pub fn merge(
field: &mut Option<OrderingWithinBlock>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<OrderingWithinBlock>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.